Documentation
¶
Index ¶
- Constants
- Variables
- func Data(msg *Message) (*capnp.Message, error)
- func SetData(msg *Message, data *capnp.Message) error
- type Message
- func (s Message) Compression() Message_Compression
- func (s Message) CorrelationID() uint64
- func (s Message) Data() ([]byte, error)
- func (s Message) Deadline() Message_deadline
- func (s Message) HasData() bool
- func (s Message) Id() uint64
- func (s Message) Packed() bool
- func (s Message) SetCompression(v Message_Compression)
- func (s Message) SetCorrelationID(v uint64)
- func (s Message) SetData(v []byte) error
- func (s Message) SetId(v uint64)
- func (s Message) SetPacked(v bool)
- func (s Message) SetTimestamp(v int64)
- func (s Message) SetType(v uint64)
- func (s Message) String() string
- func (s Message) Timestamp() int64
- func (s Message) Type() uint64
- type Message_Compression
- type Message_Compression_List
- type Message_List
- type Message_Promise
- type Message_deadline
- type Message_deadline_Promise
- type Message_deadline_Which
- type Ping
- type Ping_List
- type Ping_Promise
- type Pong
- type Pong_List
- type Pong_Promise
- type SupportedMessageTypes
- type SupportedMessageTypes_List
- type SupportedMessageTypes_Promise
- type SupportedMessageTypes_Request
- type SupportedMessageTypes_Request_List
- type SupportedMessageTypes_Request_Promise
- type SupportedMessageTypes_Response
- func NewRootSupportedMessageTypes_Response(s *capnp.Segment) (SupportedMessageTypes_Response, error)
- func NewSupportedMessageTypes_Response(s *capnp.Segment) (SupportedMessageTypes_Response, error)
- func ReadRootSupportedMessageTypes_Response(msg *capnp.Message) (SupportedMessageTypes_Response, error)
- func (s SupportedMessageTypes_Response) HasTypes() bool
- func (s SupportedMessageTypes_Response) NewTypes(n int32) (capnp.UInt64List, error)
- func (s SupportedMessageTypes_Response) SetTypes(v capnp.UInt64List) error
- func (s SupportedMessageTypes_Response) String() string
- func (s SupportedMessageTypes_Response) Types() (capnp.UInt64List, error)
- type SupportedMessageTypes_Response_List
- type SupportedMessageTypes_Response_Promise
- type UnsupportedCompressionError
Constants ¶
const Message_Compression_TypeID = 0xf8f433c185247295
Message_Compression_TypeID is the unique identifier for the type Message_Compression.
const Message_TypeID = 0xc768aaf640842a35
Message_TypeID is the unique identifier for the type Message.
const Ping_TypeID = 0x9bce611bc724ff89
Ping_TypeID is the unique identifier for the type Ping.
const Pong_TypeID = 0xf6486a286fedf2f6
Pong_TypeID is the unique identifier for the type Pong.
const SupportedMessageTypes_Request_TypeID = 0x80b38fdd614a8b73
SupportedMessageTypes_Request_TypeID is the unique identifier for the type SupportedMessageTypes_Request.
const SupportedMessageTypes_Response_TypeID = 0x87799f37b0d1886a
SupportedMessageTypes_Response_TypeID is the unique identifier for the type SupportedMessageTypes_Response.
const SupportedMessageTypes_TypeID = 0xf56d6f421703b1f7
SupportedMessageTypes_TypeID is the unique identifier for the type SupportedMessageTypes.
Variables ¶
var (
ErrNoData = errors.New("Message has no data")
)
Functions ¶
Types ¶
type Message ¶
func (Message) Compression ¶
func (s Message) Compression() Message_Compression
func (Message) CorrelationID ¶
func (Message) Deadline ¶
func (s Message) Deadline() Message_deadline
func (Message) SetCompression ¶
func (s Message) SetCompression(v Message_Compression)
func (Message) SetCorrelationID ¶
func (Message) SetTimestamp ¶
type Message_Compression ¶
type Message_Compression uint16
const ( Message_Compression_none Message_Compression = 0 Message_Compression_zlib Message_Compression = 1 )
Values of Message_Compression.
func Message_CompressionFromString ¶
func Message_CompressionFromString(c string) Message_Compression
Message_CompressionFromString returns the enum value with a name, or the zero value if there's no such value.
func (Message_Compression) String ¶
func (c Message_Compression) String() string
String returns the enum's constant name.
type Message_Compression_List ¶
func NewMessage_Compression_List ¶
func NewMessage_Compression_List(s *capnp.Segment, sz int32) (Message_Compression_List, error)
func (Message_Compression_List) At ¶
func (l Message_Compression_List) At(i int) Message_Compression
func (Message_Compression_List) Set ¶
func (l Message_Compression_List) Set(i int, v Message_Compression)
type Message_List ¶
Message_List is a list of Message.
func NewMessage_List ¶
func NewMessage_List(s *capnp.Segment, sz int32) (Message_List, error)
NewMessage creates a new list of Message.
func (Message_List) At ¶
func (s Message_List) At(i int) Message
func (Message_List) String ¶
func (s Message_List) String() string
type Message_Promise ¶
Message_Promise is a wrapper for a Message promised by a client call.
func (Message_Promise) Deadline ¶
func (p Message_Promise) Deadline() Message_deadline_Promise
func (Message_Promise) Struct ¶
func (p Message_Promise) Struct() (Message, error)
type Message_deadline ¶
type Message_deadline Message
func (Message_deadline) ExpiresOn ¶
func (s Message_deadline) ExpiresOn() int64
func (Message_deadline) SetExpiresOn ¶
func (s Message_deadline) SetExpiresOn(v int64)
func (Message_deadline) SetTimeoutMSec ¶
func (s Message_deadline) SetTimeoutMSec(v uint16)
func (Message_deadline) TimeoutMSec ¶
func (s Message_deadline) TimeoutMSec() uint16
func (Message_deadline) Which ¶
func (s Message_deadline) Which() Message_deadline_Which
type Message_deadline_Promise ¶
Message_deadline_Promise is a wrapper for a Message_deadline promised by a client call.
func (Message_deadline_Promise) Struct ¶
func (p Message_deadline_Promise) Struct() (Message_deadline, error)
type Message_deadline_Which ¶
type Message_deadline_Which uint16
const ( Message_deadline_Which_timeoutMSec Message_deadline_Which = 0 Message_deadline_Which_expiresOn Message_deadline_Which = 1 )
func (Message_deadline_Which) String ¶
func (w Message_deadline_Which) String() string
type Ping_List ¶
Ping_List is a list of Ping.
func NewPing_List ¶
NewPing creates a new list of Ping.
type Ping_Promise ¶
Ping_Promise is a wrapper for a Ping promised by a client call.
func (Ping_Promise) Struct ¶
func (p Ping_Promise) Struct() (Ping, error)
type Pong_List ¶
Pong_List is a list of Pong.
func NewPong_List ¶
NewPong creates a new list of Pong.
type Pong_Promise ¶
Pong_Promise is a wrapper for a Pong promised by a client call.
func (Pong_Promise) Struct ¶
func (p Pong_Promise) Struct() (Pong, error)
type SupportedMessageTypes ¶
func NewRootSupportedMessageTypes ¶
func NewRootSupportedMessageTypes(s *capnp.Segment) (SupportedMessageTypes, error)
func NewSupportedMessageTypes ¶
func NewSupportedMessageTypes(s *capnp.Segment) (SupportedMessageTypes, error)
func ReadRootSupportedMessageTypes ¶
func ReadRootSupportedMessageTypes(msg *capnp.Message) (SupportedMessageTypes, error)
func (SupportedMessageTypes) String ¶
func (s SupportedMessageTypes) String() string
type SupportedMessageTypes_List ¶
SupportedMessageTypes_List is a list of SupportedMessageTypes.
func NewSupportedMessageTypes_List ¶
func NewSupportedMessageTypes_List(s *capnp.Segment, sz int32) (SupportedMessageTypes_List, error)
NewSupportedMessageTypes creates a new list of SupportedMessageTypes.
func (SupportedMessageTypes_List) At ¶
func (s SupportedMessageTypes_List) At(i int) SupportedMessageTypes
func (SupportedMessageTypes_List) Set ¶
func (s SupportedMessageTypes_List) Set(i int, v SupportedMessageTypes) error
func (SupportedMessageTypes_List) String ¶
func (s SupportedMessageTypes_List) String() string
type SupportedMessageTypes_Promise ¶
SupportedMessageTypes_Promise is a wrapper for a SupportedMessageTypes promised by a client call.
func (SupportedMessageTypes_Promise) Struct ¶
func (p SupportedMessageTypes_Promise) Struct() (SupportedMessageTypes, error)
type SupportedMessageTypes_Request ¶
func NewRootSupportedMessageTypes_Request ¶
func NewRootSupportedMessageTypes_Request(s *capnp.Segment) (SupportedMessageTypes_Request, error)
func NewSupportedMessageTypes_Request ¶
func NewSupportedMessageTypes_Request(s *capnp.Segment) (SupportedMessageTypes_Request, error)
func ReadRootSupportedMessageTypes_Request ¶
func ReadRootSupportedMessageTypes_Request(msg *capnp.Message) (SupportedMessageTypes_Request, error)
func (SupportedMessageTypes_Request) String ¶
func (s SupportedMessageTypes_Request) String() string
type SupportedMessageTypes_Request_List ¶
SupportedMessageTypes_Request_List is a list of SupportedMessageTypes_Request.
func NewSupportedMessageTypes_Request_List ¶
func NewSupportedMessageTypes_Request_List(s *capnp.Segment, sz int32) (SupportedMessageTypes_Request_List, error)
NewSupportedMessageTypes_Request creates a new list of SupportedMessageTypes_Request.
func (SupportedMessageTypes_Request_List) At ¶
func (s SupportedMessageTypes_Request_List) At(i int) SupportedMessageTypes_Request
func (SupportedMessageTypes_Request_List) Set ¶
func (s SupportedMessageTypes_Request_List) Set(i int, v SupportedMessageTypes_Request) error
func (SupportedMessageTypes_Request_List) String ¶
func (s SupportedMessageTypes_Request_List) String() string
type SupportedMessageTypes_Request_Promise ¶
SupportedMessageTypes_Request_Promise is a wrapper for a SupportedMessageTypes_Request promised by a client call.
func (SupportedMessageTypes_Request_Promise) Struct ¶
func (p SupportedMessageTypes_Request_Promise) Struct() (SupportedMessageTypes_Request, error)
type SupportedMessageTypes_Response ¶
func NewRootSupportedMessageTypes_Response ¶
func NewRootSupportedMessageTypes_Response(s *capnp.Segment) (SupportedMessageTypes_Response, error)
func NewSupportedMessageTypes_Response ¶
func NewSupportedMessageTypes_Response(s *capnp.Segment) (SupportedMessageTypes_Response, error)
func ReadRootSupportedMessageTypes_Response ¶
func ReadRootSupportedMessageTypes_Response(msg *capnp.Message) (SupportedMessageTypes_Response, error)
func (SupportedMessageTypes_Response) HasTypes ¶
func (s SupportedMessageTypes_Response) HasTypes() bool
func (SupportedMessageTypes_Response) NewTypes ¶
func (s SupportedMessageTypes_Response) NewTypes(n int32) (capnp.UInt64List, error)
NewTypes sets the types field to a newly allocated capnp.UInt64List, preferring placement in s's segment.
func (SupportedMessageTypes_Response) SetTypes ¶
func (s SupportedMessageTypes_Response) SetTypes(v capnp.UInt64List) error
func (SupportedMessageTypes_Response) String ¶
func (s SupportedMessageTypes_Response) String() string
func (SupportedMessageTypes_Response) Types ¶
func (s SupportedMessageTypes_Response) Types() (capnp.UInt64List, error)
type SupportedMessageTypes_Response_List ¶
SupportedMessageTypes_Response_List is a list of SupportedMessageTypes_Response.
func NewSupportedMessageTypes_Response_List ¶
func NewSupportedMessageTypes_Response_List(s *capnp.Segment, sz int32) (SupportedMessageTypes_Response_List, error)
NewSupportedMessageTypes_Response creates a new list of SupportedMessageTypes_Response.
func (SupportedMessageTypes_Response_List) At ¶
func (s SupportedMessageTypes_Response_List) At(i int) SupportedMessageTypes_Response
func (SupportedMessageTypes_Response_List) Set ¶
func (s SupportedMessageTypes_Response_List) Set(i int, v SupportedMessageTypes_Response) error
func (SupportedMessageTypes_Response_List) String ¶
func (s SupportedMessageTypes_Response_List) String() string
type SupportedMessageTypes_Response_Promise ¶
SupportedMessageTypes_Response_Promise is a wrapper for a SupportedMessageTypes_Response promised by a client call.
func (SupportedMessageTypes_Response_Promise) Struct ¶
func (p SupportedMessageTypes_Response_Promise) Struct() (SupportedMessageTypes_Response, error)
type UnsupportedCompressionError ¶
type UnsupportedCompressionError struct {
Message_Compression
}
func (UnsupportedCompressionError) Error ¶
func (a UnsupportedCompressionError) Error() string